@@ -33,7 +33,6 @@ class Output(asyncio.Protocol):
     def write_message(self, message):
         logging.info("Sending message on USB bus: %s", str(message))
         self._transport.write(message.to_binary())
-        time.sleep(float(message.wait_after_send) / float(1000))
         self._connection.controller.new_message(message)
 
 
@@ -58,6 +57,9 @@ class VelbusUSBConnection(velbus.VelbusConnection):
     def __init__(self, device):
         velbus.VelbusConnection.__init__(self)
         self._device = device
+        self._loop = asyncio.get_event_loop()
+        self._next_send_time = 0
+        self._queue = []
         self.setup()
 
     def setup(self):
@@ -82,7 +84,6 @@ class VelbusUSBConnection(velbus.VelbusConnection):
     def stop(self):
         logging.warning("Stop executed")
         self._protocol._transport.serial().close()
-        time.sleep(1)
 
     def feed_parser(self, data):
         assert isinstance(data, bytes)
@@ -93,4 +94,17 @@ class VelbusUSBConnection(velbus.VelbusConnection):
         @return: None
         """
         assert isinstance(message, velbus.Message)
+        if self._next_send_time < self._loop.time() and len(self._queue) == 0:
+            self._send(message)
+        else:
+            self._queue.append(message)
+
+    def _pop_queue(self):
+        if self._next_send_time < self._loop.time() and len(self._queue) > 0:
+            message = self._queue.pop(0)
+            self._send(message)
+
+    def _send(self, message):
         self._protocol.write_message(message)
+        self._next_send_time = self._loop.time() + message.wait_before_send / 1000
+        self._loop.call_at(self._next_send_time, self._pop_queue)
